use v6.c;
use Test;      # a Standard module included with Rakudo 
use lib 'lib';

my $num-tests = 2;

plan $num-tests;
 
# .... tests 
#  

use-ok "Game::Quest::Quest";
use-ok "Game::Quest::Screen";

done-testing;  # optional with 'plan' 
